@@ -1,10 +1,10 @@
 package Dist::Inkt::Role::WriteCOPYRIGHT;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.022';
+our $VERSION   = '0.110';
 
 use Moose::Role;
-use List::MoreUtils qw( uniq );
+use List::Util qw( uniq );
 use Path::Tiny qw( path );
 use Path::Iterator::Rule;
 use Software::License;
